@@ -1046,6 +1046,10 @@ typedef int QmiDeprecatedWdsCdmaCauseCode;
  */
 #define QMI_WDS_CDMA_CAUSE_CODE_GENERAL_OTHER (QmiDeprecatedWdsCdmaCauseCode) QMI_WMS_CDMA_CAUSE_CODE_GENERAL_OTHER
 
+/* The following type exists just so that we can get deprecation warnings */
+G_DEPRECATED
+typedef int QmiDeprecatedProtocolError;
+
 /**
  * QMI_PROTOCOL_ERROR_QOS_UNAVAILABLE:
  *
@@ -1054,7 +1058,21 @@ typedef int QmiDeprecatedWdsCdmaCauseCode;
  * Since: 1.0
  * Deprecated: 1.22.0: Use the #QMI_PROTOCOL_ERROR_REQUESTED_NUMBER_UNSUPPORTED instead.
  */
-#define QMI_PROTOCOL_ERROR_QOS_UNAVAILABLE (QmiProtocolError) QMI_PROTOCOL_ERROR_REQUESTED_NUMBER_UNSUPPORTED
+#define QMI_PROTOCOL_ERROR_QOS_UNAVAILABLE (QmiDeprecatedProtocolError) QMI_PROTOCOL_ERROR_REQUESTED_NUMBER_UNSUPPORTED
+
+/* The following type exists just so that we can get deprecation warnings */
+G_DEPRECATED
+typedef int QmiDeprecatedWdsVerboseCallEndReasonCm;
+
+/**
+ * QMI_WDS_VERBOSE_CALL_END_REASON_CM_CONFIGURATION_FAILED:
+ *
+ * Conference (not configuration) failed.
+ *
+ * Since: 1.0
+ * Deprecated: 1.24.10: Use the correct #QMI_WDS_VERBOSE_CALL_END_REASON_CM_CONFERENCE_FAILED name instead.
+ */
+#define QMI_WDS_VERBOSE_CALL_END_REASON_CM_CONFIGURATION_FAILED (QmiDeprecatedWdsVerboseCallEndReasonCm) QMI_WDS_VERBOSE_CALL_END_REASON_CM_CONFERENCE_FAILED
 
 /**
  * qmi_message_tlv_read_gfloat:
