@@ -83,6 +83,9 @@
  * @QMI_SERVICE_CAT: Card Application Toolkit service (v1).
  * @QMI_SERVICE_RMS: Remote Management Service.
  * @QMI_SERVICE_OMA: Open Mobile Alliance device management service.
+ * @QMI_SERVICE_FOTA: Firmware Over The Air service. Since: 1.24.
+ * @QMI_SERVICE_GMS: Telit General Modem Service. Since: 1.24.
+ * @QMI_SERVICE_GAS: Telit General Application Service. Since: 1.24.
  *
  * QMI services.
  *
@@ -90,53 +93,56 @@
  */
 typedef enum {
     QMI_SERVICE_UNKNOWN = -1,
-    QMI_SERVICE_CTL = 0,
-    QMI_SERVICE_WDS = 1,
-    QMI_SERVICE_DMS = 2,
-    QMI_SERVICE_NAS = 3,
-    QMI_SERVICE_QOS = 4,
-    QMI_SERVICE_WMS = 5,
-    QMI_SERVICE_PDS = 6,
-    QMI_SERVICE_AUTH = 7,
-    QMI_SERVICE_AT = 8,
-    QMI_SERVICE_VOICE = 9,
-    QMI_SERVICE_CAT2 = 10,
-    QMI_SERVICE_UIM = 11,
-    QMI_SERVICE_PBM = 12,
-    QMI_SERVICE_QCHAT = 13,
-    QMI_SERVICE_RMTFS = 14,
-    QMI_SERVICE_TEST = 15,
-    QMI_SERVICE_LOC = 16,
-    QMI_SERVICE_SAR = 17,
-    QMI_SERVICE_IMS = 18,
-    QMI_SERVICE_ADC = 19,
-    QMI_SERVICE_CSD = 20,
-    QMI_SERVICE_MFS = 21,
-    QMI_SERVICE_TIME = 22,
-    QMI_SERVICE_TS = 23,
-    QMI_SERVICE_TMD = 24,
-    QMI_SERVICE_SAP = 25,
-    QMI_SERVICE_WDA = 26,
-    QMI_SERVICE_TSYNC = 27,
-    QMI_SERVICE_RFSA = 28,
-    QMI_SERVICE_CSVT = 29,
-    QMI_SERVICE_QCMAP = 30,
-    QMI_SERVICE_IMSP = 31,
-    QMI_SERVICE_IMSVT = 32,
-    QMI_SERVICE_IMSA = 33,
-    QMI_SERVICE_COEX = 34,
-    /* 35, reserved */
-    QMI_SERVICE_PDC = 36,
-    /* 37, reserved */
-    QMI_SERVICE_STX = 38,
-    QMI_SERVICE_BIT = 39,
-    QMI_SERVICE_IMSRTP = 40,
-    QMI_SERVICE_RFRPE = 41,
-    QMI_SERVICE_DSD = 42,
-    QMI_SERVICE_SSCTL = 43,
-    QMI_SERVICE_CAT = 224,
-    QMI_SERVICE_RMS = 225,
-    QMI_SERVICE_OMA = 226
+    QMI_SERVICE_CTL     = 0x00,
+    QMI_SERVICE_WDS     = 0x01,
+    QMI_SERVICE_DMS     = 0x02,
+    QMI_SERVICE_NAS     = 0x03,
+    QMI_SERVICE_QOS     = 0x04,
+    QMI_SERVICE_WMS     = 0x05,
+    QMI_SERVICE_PDS     = 0x06,
+    QMI_SERVICE_AUTH    = 0x07,
+    QMI_SERVICE_AT      = 0x08,
+    QMI_SERVICE_VOICE   = 0x09,
+    QMI_SERVICE_CAT2    = 0x0A,
+    QMI_SERVICE_UIM     = 0x0B,
+    QMI_SERVICE_PBM     = 0x0C,
+    QMI_SERVICE_QCHAT   = 0x0D,
+    QMI_SERVICE_RMTFS   = 0x0E,
+    QMI_SERVICE_TEST    = 0x0F,
+    QMI_SERVICE_LOC     = 0x10,
+    QMI_SERVICE_SAR     = 0x11,
+    QMI_SERVICE_IMS     = 0x12,
+    QMI_SERVICE_ADC     = 0x13,
+    QMI_SERVICE_CSD     = 0x14,
+    QMI_SERVICE_MFS     = 0x15,
+    QMI_SERVICE_TIME    = 0x16,
+    QMI_SERVICE_TS      = 0x17,
+    QMI_SERVICE_TMD     = 0x18,
+    QMI_SERVICE_SAP     = 0x19,
+    QMI_SERVICE_WDA     = 0x1A,
+    QMI_SERVICE_TSYNC   = 0x1B,
+    QMI_SERVICE_RFSA    = 0x1C,
+    QMI_SERVICE_CSVT    = 0x1D,
+    QMI_SERVICE_QCMAP   = 0x1E,
+    QMI_SERVICE_IMSP    = 0x1F,
+    QMI_SERVICE_IMSVT   = 0x20,
+    QMI_SERVICE_IMSA    = 0x21,
+    QMI_SERVICE_COEX    = 0x22,
+    /* 0x23, reserved */
+    QMI_SERVICE_PDC     = 0x24,
+    /* 0x25, reserved */
+    QMI_SERVICE_STX     = 0x26,
+    QMI_SERVICE_BIT     = 0x27,
+    QMI_SERVICE_IMSRTP  = 0x28,
+    QMI_SERVICE_RFRPE   = 0x29,
+    QMI_SERVICE_DSD     = 0x2A,
+    QMI_SERVICE_SSCTL   = 0x2B,
+    QMI_SERVICE_CAT     = 0xE0,
+    QMI_SERVICE_RMS     = 0xE1,
+    QMI_SERVICE_OMA     = 0xE2,
+    QMI_SERVICE_FOTA    = 0xE6,
+    QMI_SERVICE_GMS     = 0xE7,
+    QMI_SERVICE_GAS     = 0xE8,
 } QmiService;
 
 /**
