@@ -306,8 +306,10 @@ indication_cb (QmiDevice *device,
         QmiClientInfo *info;
 
         info = &g_array_index (client->qmi_client_info_array, QmiClientInfo, i);
+
         /* If service and CID match; or if service and broadcast, forward to
-         * the remote client */
+         * the remote client. This message may therefore be forwarded to multiple
+         * clients, all that match the conditions. */
         if ((qmi_message_get_service (message) == info->service) &&
             (qmi_message_get_client_id (message) == info->cid ||
              qmi_message_get_client_id (message) == QMI_CID_BROADCAST)) {
@@ -317,9 +319,6 @@ indication_cb (QmiDevice *device,
                 g_warning ("couldn't forward indication to client: %s", error->message);
                 g_error_free (error);
             }
-
-            /* Avoid forwarding broadcast messages multiple times */
-            break;
         }
     }
 }
@@ -331,6 +330,20 @@ device_removed_cb (QmiDevice *device,
     untrack_client (client->proxy, client);
 }
 
+static void
+register_signal_handlers (Client *client)
+{
+    /* Register for device indications */
+    client->indication_id = g_signal_connect (client->device,
+                                              "indication",
+                                              G_CALLBACK (indication_cb),
+                                              client);
+    client->device_removed_id = g_signal_connect (client->device,
+                                                  "device-removed",
+                                                  G_CALLBACK (device_removed_cb),
+                                                  client);
+}
+
 static void
 device_open_ready (QmiDevice *device,
                    GAsyncResult *res,
@@ -360,15 +373,7 @@ device_open_ready (QmiDevice *device,
         self->priv->devices = g_list_append (self->priv->devices, g_object_ref (client->device));
     }
 
-    /* Register for device indications */
-    client->indication_id = g_signal_connect (client->device,
-                                              "indication",
-                                              G_CALLBACK (indication_cb),
-                                              client);
-    client->device_removed_id = g_signal_connect (client->device,
-                                                  "device-removed",
-                                                  G_CALLBACK (device_removed_cb),
-                                                  client);
+    register_signal_handlers (client);
 
     complete_internal_proxy_open (self, client);
 
@@ -465,7 +470,8 @@ process_internal_proxy_open (QmiProxy   *self,
         g_object_unref (file);
         g_free (device_file_path);
         return TRUE;
-    }
+    } else
+        register_signal_handlers (client);
 
     g_free (device_file_path);
 
@@ -679,38 +685,35 @@ connection_readable_cb (GSocket *socket,
 
     self = client->proxy;
 
+    if (condition & G_IO_IN || condition & G_IO_PRI) {
+        r = g_input_stream_read (g_io_stream_get_input_stream (G_IO_STREAM (client->connection)),
+                                buffer,
+                                BUFFER_SIZE,
+                                NULL,
+                                &error);
+        if (r < 0) {
+            g_warning ("Error reading from istream: %s", error ? error->message : "unknown");
+            if (error)
+                g_error_free (error);
+            untrack_client (self, client);
+            return FALSE;
+        }
+
+        if (r > 0) {
+            if (!G_UNLIKELY (client->buffer))
+                client->buffer = g_byte_array_sized_new (r);
+            g_byte_array_append (client->buffer, buffer, r);
+
+            /* Try to parse input messages */
+            parse_request (self, client);
+        }
+    }
+
     if (condition & G_IO_HUP || condition & G_IO_ERR) {
         untrack_client (self, client);
         return FALSE;
     }
 
-    if (!(condition & G_IO_IN || condition & G_IO_PRI))
-        return TRUE;
-
-    r = g_input_stream_read (g_io_stream_get_input_stream (G_IO_STREAM (client->connection)),
-                             buffer,
-                             BUFFER_SIZE,
-                             NULL,
-                             &error);
-    if (r < 0) {
-        g_warning ("Error reading from istream: %s", error ? error->message : "unknown");
-        if (error)
-            g_error_free (error);
-        untrack_client (self, client);
-        return FALSE;
-    }
-
-    if (r == 0)
-        return TRUE;
-
-    /* else, r > 0 */
-    if (!G_UNLIKELY (client->buffer))
-        client->buffer = g_byte_array_sized_new (r);
-    g_byte_array_append (client->buffer, buffer, r);
-
-    /* Try to parse input messages */
-    parse_request (self, client);
-
     return TRUE;
 }
 
