@@ -216,6 +216,9 @@ context_free (Context *context)
     if (context->nmea_indication_id)
         g_signal_handler_disconnect (context->client, context->nmea_indication_id);
 
+    if (context->delete_assistance_data_indication_id)
+        g_signal_handler_disconnect (context->client, context->delete_assistance_data_indication_id);
+
     g_clear_object (&context->cancellable);
     g_clear_object (&context->client);
     g_clear_object (&context->device);
@@ -485,9 +488,12 @@ position_report_received (QmiClientLoc                         *client,
         else
             g_print ("   time source: n/a\n");
 
-        if (qmi_indication_loc_position_report_output_get_sensor_data_usage (output, &sensor_data_usage, NULL))
-            g_print ("   sensor data usage: %s\n", qmi_loc_reliability_get_string (sensor_data_usage));
-        else
+        if (qmi_indication_loc_position_report_output_get_sensor_data_usage (output, &sensor_data_usage, NULL)) {
+            g_autofree gchar *sensor_data_usage_str = NULL;
+
+            sensor_data_usage_str = qmi_loc_sensor_data_usage_build_string_from_mask (sensor_data_usage);
+            g_print ("   sensor data usage: %s\n", sensor_data_usage_str);
+        } else
             g_print ("   sensor data usage: n/a\n");
 
         if (qmi_indication_loc_position_report_output_get_session_fix_count (output, &aux32, NULL))
@@ -685,13 +691,13 @@ delete_assistance_data_received (QmiClientLoc                               *cli
     GError                 *error = NULL;
 
     if (!qmi_indication_loc_delete_assistance_data_output_get_indication_status (output, &status, &error)) {
-        g_printerr ("Couldn't delete assistance data: %s\n", error->message);
+        g_printerr ("error: couldn't delete assistance data: %s\n", error->message);
         g_error_free (error);
         operation_shutdown (FALSE);
         return;
     }
 
-    g_printerr ("Successfully deleted assistance data\n");
+    g_print ("Successfully deleted assistance data\n");
     operation_shutdown (TRUE);
 }
 
